pub struct Options<'a>(/* private fields */);Expand description
The options of a function or markup, in source order.
Duplicates are representable, so that validation can report Duplicate Option Name; a valid message has none.
Implementations
Sourceimpl<'a> Options<'a>
impl<'a> Options<'a>
Sourcepub fn with_capacity(capacity: usize) -> Self
pub fn with_capacity(capacity: usize) -> Self
No options, with room for capacity without reallocating.
Sourcepub fn push(&mut self, name: Cow<'a, str>, value: OptionValue<'a>)
pub fn push(&mut self, name: Cow<'a, str>, value: OptionValue<'a>)
Appends an option (duplicates are kept).
Sourcepub fn iter(&self) -> impl Iterator<Item = (&str, &OptionValue<'a>)>
pub fn iter(&self) -> impl Iterator<Item = (&str, &OptionValue<'a>)>
(identifier, value) pairs, in source order.
Sourcepub fn get(&self, name: &str) -> Option<&OptionValue<'a>>
pub fn get(&self, name: &str) -> Option<&OptionValue<'a>>
The value of the first option named exactly name.
Sourcepub fn into_owned(self) -> Options<'static>
pub fn into_owned(self) -> Options<'static>
The same options, owned.