pub struct Parsed<'src> {
pub message: Option<Message<'src>>,
pub diagnostics: Diagnostics,
}Expand description
The result of parsing one message.
Fields
message: Option<Message<'src>>Some whenever the source has no syntax error — also when it has
data-model errors, which are then in diagnostics.
diagnostics: DiagnosticsEvery syntax error the frontend could recover to (with spans); when there is none, every data-model error.