pub struct Attributes<'a>(/* private fields */);Expand description
The attributes of an expression or markup, in source order; a None
value is the spec’s true (an attribute written without a value).
Implementations
Sourceimpl<'a> Attributes<'a>
impl<'a> Attributes<'a>
Sourcepub fn with_capacity(capacity: usize) -> Self
pub fn with_capacity(capacity: usize) -> Self
No attributes, with room for capacity without reallocating.
Sourcepub fn push(&mut self, name: Cow<'a, str>, value: Option<Literal<'a>>)
pub fn push(&mut self, name: Cow<'a, str>, value: Option<Literal<'a>>)
Appends an attribute (duplicates are kept).
Sourcepub fn iter(&self) -> impl Iterator<Item = (&str, Option<&Literal<'a>>)>
pub fn iter(&self) -> impl Iterator<Item = (&str, Option<&Literal<'a>>)>
(identifier, value) pairs, in source order.
Sourcepub fn get(&self, name: &str) -> Option<Option<&Literal<'a>>>
pub fn get(&self, name: &str) -> Option<Option<&Literal<'a>>>
The value of the last attribute named exactly name — all but the
last are ignored (syntax.md, “Attributes”): None if there is
none, Some(None) if it has no value.
Sourcepub fn into_owned(self) -> Attributes<'static>
pub fn into_owned(self) -> Attributes<'static>
The same attributes, owned.